print_error

Function print_error 

pub fn print_error(noun: &'static str, op: &'static str, err: &OpError)
Print a typed error in the JSON envelope and return the same error so the caller can map it to the process exit code.